/* myTimer -- the timing object for doing lsystem graph-interpretation
	using RTcmix WAVETABLE instrument.  "myTimer.C" is
	the animator object (can't use RTtimeit because of graphics
	context problems)  -- BGG/2003
*/

#include "wx/wxprec.h"

#ifndef WX_PRECOMP
	#include "wx/wx.h"
#endif

#include "myTimer.h"
#include <iostream.h>


myTimer::myTimer(wxClientDC *thedc, RTcmix *rt)
{
	// the graphics context (for drawing) and the RTcmix object
	// are set in the calling program
	wdc = thedc;
	rrr = rt;
}

void myTimer::setX(int startx)
{
	x = startx;
	y = 0;
}

void myTimer::Notify()
{
// this is where the work is done -- Notify() is called periodically
// 	we will use this to check how many red pixels (zero-blue) are
//	in a square we periodically lay out.  We then grab pitches
//	from the pitches[] array and send of RTcmix WAVETABLEs

	int i;
	int pvalcounter;
	float pitches[14] = { 8.00, 8.07, 7.10, 7.05, 8.03, 7.00, 9.07, 8.02,
		6.03, 9.10, 6.00, 10.02, 5.08, 10.05 };
	wxColour check;

	// the square we draw, advance x and y appropriately
	wdc->SetPen(*wxGREEN_PEN);
	wdc->SetBrush(*wxTRANSPARENT_BRUSH);
	wdc->DrawRectangle(x, y, 15, 30);

	pvalcounter = 0;
	for (i = 0; i < 29; i++) // check for red pixels in a x-section
	{
		wdc->GetPixel(x+7, y+i, &check);
		if (check.Blue() == 0) pvalcounter++;
	}
	if (pvalcounter > 14) pvalcounter = 14;

	for (i = 0; i < pvalcounter; i++) // send off them notes!
	{
		rrr->cmd("WAVETABLE", 5, 0.0, 0.1, 3000.0, pitches[i], 0.5);
	}

	// set up for the next square, or move to the next column
	y+= 30;
	if (y > 470)
	{
		y = 0;
		x+= 15;
	}

	if (x > 1000) Stop();  // end of the graph
}
